from . import _init_controller

# autogenerated by 'robotpy-build create-imports wpilib.controller'
from ._controller import (
    HolonomicDriveController,
    PIDController,
    ProfiledPIDController,
    ProfiledPIDControllerRadians,
    RamseteController,
)

__all__ = [
    "HolonomicDriveController",
    "PIDController",
    "ProfiledPIDController",
    "ProfiledPIDControllerRadians",
    "RamseteController",
]

# 2020 compatibility to be removed in 2022
from wpimath.controller import (
    ArmFeedforward,
    ElevatorFeedforward,
    SimpleMotorFeedforward,
    SimpleMotorFeedforwardMeters,
)
